package com.install4j.api.beans;

import java.awt.*;

/**
 * Property type for an anchor.
 *
 * @author ej-technologies GmbH
 */

public enum Anchor {

    NORTHWEST("North-West", GridBagConstraints.FIRST_LINE_START),
    NORTH("North", GridBagConstraints.PAGE_START),
    NORTHEAST("North-East", GridBagConstraints.FIRST_LINE_END),
    WEST("West", GridBagConstraints.LINE_START),
    CENTER("Center", GridBagConstraints.CENTER),
    EAST("East", GridBagConstraints.LINE_END),
    SOUTHWEST("South-West", GridBagConstraints.LAST_LINE_START),
    SOUTH("South", GridBagConstraints.PAGE_END),
    SOUTHEAST("South-East", GridBagConstraints.LAST_LINE_END);

    /**
     * Get the anchor constant that corresponds to the specified value
     * @param value the value, as returned by {@link #getValue()}
     * @see #getValue()
     * @return the anchor or {@code null} if the value cannot be found
     */
    public static Anchor getByValue(int value) {
        for (Anchor anchor : values()) {
            if (anchor.getValue() == value) {
                return anchor;
            }
        }
        return null;
    }

    private String verbose;
    private int value;

    Anchor(String verbose, int value) {
        this.verbose = verbose;
        this.value = value;
    }

    /**
     * The value of the anchor which can be used by {@code java.awt.GridBagLayout}.
     * @return the value, one of the anchor constants in {@code java.awt.GridBagConstraints}
     */
    public int getValue() {
        return value;
    }

    @Override
    public String toString() {
        return verbose;
    }

}
