package com.install4j.api.events;

import com.install4j.api.context.Context;

/**
 * The event object that is passed to installer event listeners after an action has been executed.
 * Event listeners are registered in the {@link com.install4j.api.context.InstallerContext}.
 * <p>This event object contains additional information about the duration of the action.
 * @author ej-technologies GmbH
 * @see InstallerEventListener
 * @see com.install4j.api.context.InstallerContext#addInstallerEventListener(InstallerEventListener)
 *
 */
public class InstallerActionEvent extends InstallerEvent {

    private long duration;

    /**
     * The constructor is called by the framework.
     * @param source the event source
     * @param context the context
     * @param type the event type.
     * @param success whether the operation associated with the event was successful
     * @param duration the duration in milliseconds
     */
    public InstallerActionEvent(Object source, Context context, EventType type, boolean success, long duration) {
        super(source, context, type, success);
        this.duration = duration;
    }

    /**
     * Returns the duration of the action in milliseconds
     * @return the duration in milliseconds
     */
    public long getDuration() {
        return duration;
    }

    @Override
    public String toString() {
        return super.toString() + "[duration " + duration + " ms]";
    }

    @Override
    public String getVerbose() {
        return super.getVerbose() + " after " + duration + " ms";
    }
}
